package org.basex.modules.fop;

import javax.xml.transform.*;
import javax.xml.transform.sax.*;
import javax.xml.transform.stream.*;

import org.apache.fop.apps.*;
import org.apache.xmlgraphics.util.MimeConstants;
import org.basex.io.in.*;
import org.basex.io.out.*;
import org.basex.query.*;
import org.basex.query.value.item.*;
import org.basex.query.value.node.*;

/**
 * This module converts FO files to PDF.
 *
 * @author BaseX Team 2005-12, BSD License
 * @author Adrian Berila
 * @author Cristian Chiric
 * @author Christian Gruen
 */
public class FOP extends QueryModule {
	/**
	 * Converts an FO representation to PDF, using FOP.
   * @param node input node
	 * @return PDF document
	 * @throws QueryException query exception
	 */
  @Requires(Permission.NONE)
  @Deterministic
	public B64 transform(final ANode node) throws QueryException {
	  return transform(node, MimeConstants.MIME_PDF);
	}

  /**
   * Transforms an FO input node to the specified format.
   * @param node input node
   * @param format mime-type of output format (usually: {@code application/pdf})
   * @return transformed document
   * @throws QueryException query exception
   */
  @Requires(Permission.NONE)
  @Deterministic
  public B64 transform(final ANode node, final String format) throws QueryException {
    try {
      // configure fop factory and user agent
      final FopFactory ff = FopFactory.newInstance();
      final FOUserAgent fa = ff.newFOUserAgent();

      // output stream
      final ArrayOutput ao = new ArrayOutput();

      // construct fop with desired output format
      final Fop fop = ff.newFop(format, fa, ao);

      // setup JAXP using identity transformer
      final TransformerFactory tf = TransformerFactory.newInstance();
      final Transformer tr = tf.newTransformer();

      // setup input stream
      final Source src = new StreamSource(new ArrayInput(node.serialize().toArray()));

      // do transformation
      tr.transform(src, new SAXResult(fop.getDefaultHandler()));

      return B64.get(ao.toArray());

    } catch(final Exception ex) {
      ex.printStackTrace();
      throw new QueryException(ex);
    }
  }
}
